==> tlotd-0.3.8%20-%201.20.1-sources.jar: net/tlotd/block/custom/OxygenCollectorBlock.java <==
package net.tlotd.block.custom;

import net.minecraft.block.*;
import net.minecraft.class_124;
import net.minecraft.class_1264;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2318;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_2350;
import net.minecraft.class_2464;
import net.minecraft.class_2470;
import net.minecraft.class_2561;
import net.minecraft.class_2586;
import net.minecraft.class_259;
import net.minecraft.class_2591;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2753;
import net.minecraft.class_3610;
import net.minecraft.class_3612;
import net.minecraft.class_3726;
import net.minecraft.class_3908;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_5558;
import net.minecraft.util.*;
import net.tlotd.block.entity.MithrilAnvilBlockEntity;
import net.tlotd.block.entity.ModBlockEntities;
import net.tlotd.block.entity.OxygenCollectorBlockEntity;
import net.tlotd.util.ModTags;
import org.jetbrains.annotations.Nullable;

import java.util.List;

public class OxygenCollectorBlock extends class_2237 implements class_2343 {

    public static final class_2746 WATERLOGGED = class_2741.field_12508;

    public static final class_2753 FACING = class_2318.field_10927;

    @Override
    public boolean method_9558(class_2680 state, class_4538 world, class_2338 pos) {
        return (world.method_8320(pos.method_10069(0,-1,0)).method_26164(ModTags.Blocks.OXYGEN_PROVIDERS) && !world.method_8320(pos.method_10069(0,-1,0)).method_27852(class_2246.field_10495));
    }

    @Override
    public class_2680 method_9605(class_1750 ctx) {
        return this.method_9564()
                .method_11657(FACING, ctx.method_8042())
                .method_11657(WATERLOGGED, ctx.method_8045().method_8316(ctx.method_8037()).method_39360(class_3612.field_15910));
    }

    @Override
    public class_3610 method_9545(class_2680 state) {
        return state.method_11654(WATERLOGGED) ? class_3612.field_15910.method_15729(false) : super.method_9545(state);
    }

    @Override
    public class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        if (state.method_11654(WATERLOGGED)) {
            world.method_39281(pos, class_3612.field_15910, class_3612.field_15910.method_15789(world));
        }

        return !state.method_26184(world, pos) ? class_2246.field_10124.method_9564() : super.method_9559(state, direction, neighborState, world, pos, neighborPos);
    }

    @Override
    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return state.method_11657(FACING, rotation.method_10503(state.method_11654(FACING)));
    }

    @Override
    public void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FACING, WATERLOGGED);
    }

    public OxygenCollectorBlock(class_2251 settings) {
        super(settings);
        this.method_9590(this.field_10647.method_11664().method_11657(FACING, class_2350.field_11043).method_11657(WATERLOGGED, false));
    }

    private static final class_265 BASE_SHAPE = class_2248.method_9541(0,-16,0,16,4,16);

    public static final class_265 EAST_SHAPE = class_259.method_17786(
            class_2248.method_9541(0.0, 4.0, 4.0, 16.0, 16.0, 12.0),
            class_2248.method_9541(7.0, 4.0, 1.0, 13.0, 11.0, 15.0),
            BASE_SHAPE);
    public static final class_265 SOUTH_SHAPE = class_259.method_17786(
            class_2248.method_9541(4.0, 4.0, 0.0, 12.0, 16.0, 16.0),
            class_2248.method_9541(1.0, 4.0, 7.0, 15.0, 11.0, 13.0),
            BASE_SHAPE);
    public static final class_265 WEST_SHAPE = class_259.method_17786(
            class_2248.method_9541(0.0, 4.0, 4.0, 16.0, 16.0, 12.0),
            class_2248.method_9541(3.0, 4.0, 1.0, 9.0, 11.0, 15.0),
            BASE_SHAPE);
    public static final class_265 NORTH_SHAPE = class_259.method_17786(
            class_2248.method_9541(4.0, 4.0, 0.0, 12.0, 16.0, 16.0),
            class_2248.method_9541(1.0, 4.0, 3.0, 15.0, 11.0, 9.0),
            BASE_SHAPE);

    @Override
    public class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return switch (state.method_11654(FACING)) {
            case field_11034 -> EAST_SHAPE;
            case field_11035 -> SOUTH_SHAPE;
            case field_11039 -> WEST_SHAPE;
            default -> NORTH_SHAPE;
        };
    }

    @Override
    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11458;
    }

    @Override
    public void method_9568(class_1799 stack, @Nullable class_1922 world, List<class_2561> tooltip, class_1836 options) {
        tooltip.add(class_2561.method_43470(""));
        tooltip.add(class_2561.method_43471("block.tlotd.oxygen_collector.tooltip").method_27692(class_124.field_1080));
        tooltip.add(class_2561.method_43470(" ").method_10852(class_2561.method_43471("block.tlotd.oxygen_collector.tooltip_2")).method_27692(class_124.field_1078));
        super.method_9568(stack, world, tooltip, options);
    }

    @Override
    public @Nullable class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new OxygenCollectorBlockEntity(pos, state);
    }

    @Override
    public void method_9536(class_2680 state, class_1937 world, class_2338 pos, class_2680 newState, boolean moved) {
        if (state.method_26204() != newState.method_26204()) {
            class_2586 blockEntity = world.method_8321(pos);
            if (blockEntity instanceof OxygenCollectorBlockEntity) {
                class_1264.method_5451(world, pos, (OxygenCollectorBlockEntity)blockEntity);
                world.method_8455(pos, this);
            }
            super.method_9536(state, world, pos, newState, moved);
        }
    }

    @Override
    public class_1269 method_9534(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_1268 hand, class_3965 hit) {
        if (!world.field_9236) {
            class_3908 screenHandlerFactory = ((OxygenCollectorBlockEntity) world.method_8321(pos));
            if (screenHandlerFactory != null) {
                player.method_17355(screenHandlerFactory);
            }
        }
        return class_1269.field_5812;
    }

    @Override
    public @Nullable <T extends class_2586> class_5558<T> method_31645(class_1937 world, class_2680 state, class_2591<T> type) {
        return method_31618(type, ModBlockEntities.OXYGEN_COLLECTOR_BLOCK_ENTITY,
                (world1, pos, state1, blockEntity) -> blockEntity.tick(world1, pos, state1));
    }
}

==> tlotd-0.3.9%20-%201.20.1-sources.jar: net/tlotd/block/custom/OxygenCollectorBlock.java <==
package net.tlotd.block.custom;

import net.minecraft.block.*;
import net.minecraft.class_124;
import net.minecraft.class_1264;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2318;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_2350;
import net.minecraft.class_2464;
import net.minecraft.class_2470;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2586;
import net.minecraft.class_259;
import net.minecraft.class_2591;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2753;
import net.minecraft.class_2960;
import net.minecraft.class_3610;
import net.minecraft.class_3612;
import net.minecraft.class_3726;
import net.minecraft.class_3908;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_5558;
import net.minecraft.util.*;
import net.tlotd.block.entity.ModBlockEntities;
import net.tlotd.block.entity.OxygenCollectorBlockEntity;
import net.tlotd.util.ModTags;
import org.jetbrains.annotations.Nullable;

import java.util.List;

public class OxygenCollectorBlock extends class_2237 implements class_2343 {

    public static final class_2746 WATERLOGGED = class_2741.field_12508;

    public static final class_2753 FACING = class_2318.field_10927;

    @Override
    public boolean method_9558(class_2680 state, class_4538 world, class_2338 pos) {
        return (world.method_8320(pos.method_10069(0,-1,0)).method_26164(ModTags.Blocks.OXYGEN_PROVIDERS) && !world.method_8320(pos.method_10069(0,-1,0)).method_27852(class_2246.field_10495));
    }

    @Override
    public class_2680 method_9605(class_1750 ctx) {
        return this.method_9564()
                .method_11657(FACING, ctx.method_8042())
                .method_11657(WATERLOGGED, ctx.method_8045().method_8316(ctx.method_8037()).method_39360(class_3612.field_15910));
    }

    @Override
    public class_3610 method_9545(class_2680 state) {
        return state.method_11654(WATERLOGGED) ? class_3612.field_15910.method_15729(false) : super.method_9545(state);
    }

    @Override
    public class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        if (state.method_11654(WATERLOGGED)) {
            world.method_39281(pos, class_3612.field_15910, class_3612.field_15910.method_15789(world));
        }

        return !state.method_26184(world, pos) ? class_2246.field_10124.method_9564() : super.method_9559(state, direction, neighborState, world, pos, neighborPos);
    }

    @Override
    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return state.method_11657(FACING, rotation.method_10503(state.method_11654(FACING)));
    }

    @Override
    public void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FACING, WATERLOGGED);
    }

    public OxygenCollectorBlock(class_2251 settings) {
        super(settings);
        this.method_9590(this.field_10647.method_11664().method_11657(FACING, class_2350.field_11043).method_11657(WATERLOGGED, false));
    }

    private static final class_265 BASE_SHAPE = class_2248.method_9541(0,-16,0,16,4,16);

    public static final class_265 EAST_SHAPE = class_259.method_17786(
            class_2248.method_9541(0.0, 4.0, 4.0, 16.0, 16.0, 12.0),
            class_2248.method_9541(7.0, 4.0, 1.0, 13.0, 11.0, 15.0),
            BASE_SHAPE);
    public static final class_265 SOUTH_SHAPE = class_259.method_17786(
            class_2248.method_9541(4.0, 4.0, 0.0, 12.0, 16.0, 16.0),
            class_2248.method_9541(1.0, 4.0, 7.0, 15.0, 11.0, 13.0),
            BASE_SHAPE);
    public static final class_265 WEST_SHAPE = class_259.method_17786(
            class_2248.method_9541(0.0, 4.0, 4.0, 16.0, 16.0, 12.0),
            class_2248.method_9541(3.0, 4.0, 1.0, 9.0, 11.0, 15.0),
            BASE_SHAPE);
    public static final class_265 NORTH_SHAPE = class_259.method_17786(
            class_2248.method_9541(4.0, 4.0, 0.0, 12.0, 16.0, 16.0),
            class_2248.method_9541(1.0, 4.0, 3.0, 15.0, 11.0, 9.0),
            BASE_SHAPE);

    @Override
    public class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return switch (state.method_11654(FACING)) {
            case field_11034 -> EAST_SHAPE;
            case field_11035 -> SOUTH_SHAPE;
            case field_11039 -> WEST_SHAPE;
            default -> NORTH_SHAPE;
        };
    }

    @Override
    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11458;
    }

    public static final class_2960 DEFAULT_FONT_ID = new class_2960("minecraft", "default");
    public static final class_2960 MODS_FONT_ID = new class_2960("tlotd", "mods");

    @Override
    public void method_9568(class_1799 stack, @Nullable class_1922 world, List<class_2561> tooltip, class_1836 options) {
        class_2583 style = this.method_9518().method_10866();
        if (options.method_47370()){
            tooltip.add(class_2561.method_43470("\uE015 ").method_10862(style.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.ad_astra.name").method_10862(style.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
        }
        tooltip.add(class_2561.method_43470(""));
        tooltip.add(class_2561.method_43471("block.tlotd.oxygen_collector.tooltip").method_27692(class_124.field_1080));
        tooltip.add(class_2561.method_43470(" ").method_10852(class_2561.method_43471("block.tlotd.oxygen_collector.tooltip_2")).method_27692(class_124.field_1078));
        super.method_9568(stack, world, tooltip, options);
    }

    @Override
    public @Nullable class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new OxygenCollectorBlockEntity(pos, state);
    }

    @Override
    public void method_9536(class_2680 state, class_1937 world, class_2338 pos, class_2680 newState, boolean moved) {
        if (state.method_26204() != newState.method_26204()) {
            class_2586 blockEntity = world.method_8321(pos);
            if (blockEntity instanceof OxygenCollectorBlockEntity) {
                class_1264.method_5451(world, pos, (OxygenCollectorBlockEntity)blockEntity);
                world.method_8455(pos, this);
            }
            super.method_9536(state, world, pos, newState, moved);
        }
    }

    @Override
    public class_1269 method_9534(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_1268 hand, class_3965 hit) {
        if (!world.field_9236) {
            class_3908 screenHandlerFactory = ((OxygenCollectorBlockEntity) world.method_8321(pos));
            if (screenHandlerFactory != null) {
                player.method_17355(screenHandlerFactory);
            }
        }
        return class_1269.field_5812;
    }

    @Override
    public @Nullable <T extends class_2586> class_5558<T> method_31645(class_1937 world, class_2680 state, class_2591<T> type) {
        return method_31618(type, ModBlockEntities.OXYGEN_COLLECTOR_BLOCK_ENTITY,
                (world1, pos, state1, blockEntity) -> blockEntity.tick(world1, pos, state1));
    }
}
